class APIError(Exception):
    def __init__(self, message="An error occurred with the API"):
        self.message = message
        super().__init__(self.message)

class BadKeyError(APIError):
    def __init__(self, message="Bad API Key. Please check your key."):
        self.message = message
        super().__init__(self.message)

class NoIdRentError(APIError):
    def __init__(self, message="No ID Rent. Please check your rent ID."):
        self.message = message
        super().__init__(self.message)

class InvalidPhoneError(APIError):
    def __init__(self, message="Invalid Phone ID Rent."):
        self.message = message
        super().__init__(self.message)

class ServerError(APIError):
    def __init__(self, message="Server error. Please try again later."):
        self.message = message
        super().__init__(self.message)

class InvalidTimeError(APIError):
    def __init__(self, message="Invalid rental time. Please check the time parameter."):
        self.message = message
        super().__init__(self.message)

class BadCountryError(APIError):
    def __init__(self, message="Bad country code. Please check the country code."):
        self.message = message
        super().__init__(self.message)

class BadServiceError(APIError):
    def __init__(self, message="Bad service code. Please check the service code."):
        self.message = message
        super().__init__(self.message)

class NoNumbersError(APIError):
    def __init__(self, message="No Nums available. Try again later."):
        self.message = message
        super().__init__(self.message)


"""
from GrizzlySMS-API import GrizzlySMS
api_key = "YOUR_API_KEY"
grizzly = GrizzlySMS(api_key)
rent_id = "your_rent_id"
try:
    rent_status = grizzly.get_rent_status(rent_id)
    print("Rent Status:", rent_status)
except APIError as e:
    print(f"API Error: {e}")
service = "select-service-plug"
country = "US"
time = 240
try:
    rent_prices = grizzly.get_rent_prices(service, country, time)
    print("Rent Prices:", rent_prices)
except APIError as e:
    print(f"API Error: {e}")
try:
    number_data = grizzly.get_number(service, country)
    print("Number Data:", number_data)
except APIError as e:
    print(f"API Error: {e}")
try:
    balance_data = grizzly.get_balance()
    print("Balance:", balance_data)
except APIError as e:
    print(f"API Error: {e}")
try:
    rent_status_by_id = grizzly.get_rent_status_by_id(rent_id)
    print("Rent Status by ID:", rent_status_by_id)
except APIError as e:
    print(f"API Error: {e}")
try:
    rent_prices_by_country = grizzly.get_rent_prices_by_country(service, country, time)
    print("Rent Prices by Country:", rent_prices_by_country)
except APIError as e:
    print(f"API Error: {e}")
[[[ Example Of Use ]]]
"""

from .grizzly import GrizzlySMS

__version__ = '0.0.2'
user_ ='ILY'


import requests
import json
from .errors import APIError, BadKeyError, NoIdRentError, InvalidPhoneError, ServerError, InvalidTimeError, BadCountryError, BadServiceError, NoNumbersError

class GrizzlySMS:
    def __init__(self, api_key):
        self.api_key = api_key
        self.base_url = "https://api.grizzlysms.com/stubs/handler_api.php"

    def get_rent_status(self, rent_id):
        params = {
            'api_key': self.api_key,
            'action': 'getRentStatus',
            'id': rent_id#https://GrizzlySMS.com/Rent or SMTH idk.
        }
        response = requests.get(self.base_url, params=params)
        return self._handle_response(response)

    def get_rent_prices(self, service, country, time):
        params = {
            'api_key': self.api_key,
            'action': 'getRentPrices',
            'service': service,
            'country': country,
            'rent_time': time
        }
        response = requests.get(self.base_url, params=params)
        return self._handle_response(response)

    def get_number(self, service, country):
        params = {
            'api_key': self.api_key,
            'action': 'getNumber',
            'service': service,
            'country': country
        }
        response = requests.get(self.base_url, params=params)
        return self._handle_response(response)

    def get_balance(self):
        params = {
            'api_key': self.api_key,
            'action': 'getBalance'
        }
        response = requests.get(self.base_url, params=params)
        return self._handle_response(response)

    def get_rent_status_by_id(self, rent_id):
        params = {
            'api_key': self.api_key,
            'action': 'getRentStatus',
            'id': rent_id
        }
        response = requests.get(self.base_url, params=params)
        return self._handle_response(response)

    def get_rent_prices_by_country(self, service, country, time):
        params = {
            'api_key': self.api_key,
            'action': 'getRentPrices',
            'service': service,
            'country': country,
            'rent_time': time
        }
        response = requests.get(self.base_url, params=params)
        return self._handle_response(response)

    def _handle_response(self, response):
        try:
            data = response.json()
            
            if data.get("status") == "error":
                self._handle_error(data)
            
            return data
        except json.JSONDecodeError:
            print(f"Response text: {response.text}")
            return {"error": "Response is not in JSON format"}
        except Exception as e:
            print(f"Error: {e}")
            return {"error": str(e)}

    def _handle_error(self, data):
        error_code = data.get("error", "")
        if error_code == "BAD_KEY":
            raise BadKeyError()
        elif error_code == "NO_ID_RENT":
            raise NoIdRentError()
        elif error_code == "INVALID_PHONE":
            raise InvalidPhoneError()
        elif error_code == "SERVER_ERROR":
            raise ServerError()
        elif error_code == "INVALID_TIME":
            raise InvalidTimeError()
        elif error_code == "BAD_COUNTRY":
            raise BadCountryError()
        elif error_code == "BAD_SERVICE":
            raise BadServiceError()
        elif error_code == "NO_NUMBERS":
            raise NoNumbersError()
        else:
            raise APIError("Unknown error occurred.")